package com.zbf.system.service;

import java.util.List;

import com.zbf.system.domain.TckOrderdetailBak;
import com.zbf.system.domain.TckOrdersBak;

/**
 * 出库单历史表Service接口
 *
 * @author tony
 * @date 2024-07-03
 */
public interface ITckOrdersBakService
{
    /**
     * 查询出库单历史表
     *
     * @param id 出库单历史表主键
     * @return 出库单历史表
     */
    public TckOrdersBak selectTckOrdersBakById(String id);

    /**
     * 查询出库单历史表列表
     *
     * @param tckOrdersBak 出库单历史表
     * @return 出库单历史表集合
     */
    public List<TckOrdersBak> selectTckOrdersBakList(TckOrdersBak tckOrdersBak);

    /**
     * 查询出库明细数据（退库入库用）
     * @param tckOrderdetailBak
     * @return
     */
    public List<TckOrderdetailBak> selectReturnTckOrdersBakList(TckOrderdetailBak tckOrderdetailBak);

    /**
     * 新增出库单历史表
     *
     * @param tckOrdersBak 出库单历史表
     * @return 结果
     */
    public int insertTckOrdersBak(TckOrdersBak tckOrdersBak);

    /**
     * 修改出库单历史表
     *
     * @param tckOrdersBak 出库单历史表
     * @return 结果
     */
    public int updateTckOrdersBak(TckOrdersBak tckOrdersBak);

    /**
     * 批量删除出库单历史表
     *
     * @param ids 需要删除的出库单历史表主键集合
     * @return 结果
     */
    public int deleteTckOrdersBakByIds(String[] ids);

    /**
     * 删除出库单历史表信息
     *
     * @param id 出库单历史表主键
     * @return 结果
     */
    public int deleteTckOrdersBakById(String id);

    /**
     * 批量禁用出库单历史表
     *
     * @param ids 需要禁用的出库单历史表主键集合
     * @return 结果
     */
    public int disabledTckOrdersBakByIds(String[] ids);

    /**
     * 批量启用出库单历史表
     *
     * @param ids 需要启用的出库单历史表主键集合
     * @return 结果
     */
    public int enableTckOrdersBakByIds(String[] ids);

    /**
     * 改变状态
     *
     * @param tckOrdersBak
     * @return 结果
     */
    public int updateStatus(TckOrdersBak tckOrdersBak);
}

